@@ -1,7 +1,7 @@
 /*
  * frogr-about-dialog.c -- About dialog
  *
- * Copyright (C) 2009, 2010 Mario Sanchez Prada
+ * Copyright (C) 2009, 2010, 2011 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@igalia.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -30,20 +30,20 @@
 #define ABOUT_DIALOG_ICON ICONS_DIR "/hicolor/48x48/apps/frogr.png"
 
 static const gchar *authors[] = {
-  "Mario Sanchez Prada\n<msanchez@igalia.com>",
+  "Mario Sanchez Prada <msanchez@igalia.com>",
+  "Adrian Perez de Castro <aperez@igalia.com>",
   "",
-  "Adrian Perez de Castro\n<aperez@igalia.com>",
   NULL
 };
 
 static const gchar *artists[] = {
-  "Adrian Perez de Castro\n<aperez@igalia.com>",
+  "Adrian Perez de Castro <aperez@igalia.com>",
   NULL
 };
 
 static const gchar *appdescr = N_("A Flickr remote organizer for GNOME\n");
-static const gchar *copyright = "(c) 2009, 2010 Mario Sanchez Prada";
-static const gchar *website = "http://code.google.com/p/frogr";
+static const gchar *copyright = "(c) 2009, 2010, 2011 Mario Sanchez Prada";
+static const gchar *website = "http://live.gnome.org/Frogr";
 static const gchar *license =
   "frogr is free software: you can redistribute\n"
   "it and/or modify it under the terms of the GNU\n"
@@ -63,6 +63,7 @@ static const gchar *license =
   "library (which comes bundled-in with frogr), but\n"
   "it's neither approved nor certified by flickr.";
 
+#if !GTK_CHECK_VERSION (2,23,0)
 static void
 _frogr_about_dialog_uri_hook (GtkAboutDialog *about,
                               const gchar *link,
@@ -72,16 +73,24 @@ _frogr_about_dialog_uri_hook (GtkAboutDialog *about,
   frogr_util_open_url_in_browser (uri);
   g_free (uri);
 }
+#endif
 
 void
 frogr_about_dialog_show (GtkWindow *parent)
 {
-  GdkPixbuf *logo = gdk_pixbuf_new_from_file (ABOUT_DIALOG_ICON, NULL);
+  GdkPixbuf *logo = NULL;
+  char *version = NULL;
 
+  logo = gdk_pixbuf_new_from_file (ABOUT_DIALOG_ICON, NULL);
+
+#if !GTK_CHECK_VERSION (2,23,0)
   /* Install about dialog hooks */
   gtk_about_dialog_set_url_hook (_frogr_about_dialog_uri_hook, "", NULL);
   gtk_about_dialog_set_email_hook (_frogr_about_dialog_uri_hook, "mailto:",
                                    NULL);
+#endif
+
+  version = g_strdup_printf ("%s", VERSION);
 
   /* Show about dialog */
   gtk_show_about_dialog (GTK_WINDOW (parent),
@@ -91,11 +100,13 @@ frogr_about_dialog_show (GtkWindow *parent)
                          "comments", _(appdescr),
                          "copyright", copyright,
                          "license", license,
-                         "version", VERSION,
+                         "version", version,
                          "website", website,
                          "logo", logo,
+                         "translator-credits", _("translator-credits"),
                          "modal", TRUE,
                          NULL);
 
   g_object_unref (logo);
+  g_free (version);
 }
