@@ -1,7 +1,7 @@
 /*
  * frogr-details-dialog.h -- Picture details dialog
  *
- * Copyright (C) 2009, 2010 Mario Sanchez Prada
+ * Copyright (C) 2009, 2010, 2011 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@igalia.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -49,7 +49,7 @@ struct _FrogrDetailsDialog
 
 GType frogr_details_dialog_get_type (void) G_GNUC_CONST;
 
-void frogr_details_dialog_show (GtkWindow *parent, GSList *fpictures);
+void frogr_details_dialog_show (GtkWindow *parent, GSList *fpictures, GSList *tags);
 
 G_END_DECLS  /* FROGR_DETAILS_DIALOG_H */
 
