@@ -1,7 +1,7 @@
 /*
  * frogr-picture.c -- A picture in frogr
  *
- * Copyright (C) 2009, 2010 Mario Sanchez Prada
+ * Copyright (C) 2009, 2010, 2011 Mario Sanchez Prada
  * Authors: Mario Sanchez Prada <msanchez@igalia.com>
  *
  * This program is free software; you can redistribute it and/or
@@ -42,12 +42,17 @@ struct _FrogrPicturePrivate
   gchar *tags_string;
   GSList *tags_list;
 
-  GSList *albums;
+  GSList *sets;
+  GSList *groups;
 
   gboolean is_public;
   gboolean is_friend;
   gboolean is_family;
 
+  FspSafetyLevel safety_level;
+  FspContentType content_type;
+  gboolean show_in_search;
+
   GdkPixbuf *pixbuf;
 };
 
@@ -62,6 +67,9 @@ enum  {
   PROP_IS_PUBLIC,
   PROP_IS_FAMILY,
   PROP_IS_FRIEND,
+  PROP_SAFETY_LEVEL,
+  PROP_CONTENT_TYPE,
+  PROP_SHOW_IN_SEARCH,
   PROP_PIXBUF
 };
 
@@ -199,6 +207,15 @@ _frogr_picture_set_property (GObject *object,
     case PROP_IS_FRIEND:
       frogr_picture_set_friend (self, g_value_get_boolean (value));
       break;
+    case PROP_SAFETY_LEVEL:
+      frogr_picture_set_safety_level (self, g_value_get_int (value));
+      break;
+    case PROP_CONTENT_TYPE:
+      frogr_picture_set_content_type (self, g_value_get_int (value));
+      break;
+    case PROP_SHOW_IN_SEARCH:
+      frogr_picture_set_show_in_search (self, g_value_get_boolean (value));
+      break;
     case PROP_PIXBUF:
       frogr_picture_set_pixbuf (self, GDK_PIXBUF (g_value_get_object (value)));
       break;
@@ -242,6 +259,15 @@ _frogr_picture_get_property (GObject *object,
     case PROP_IS_FRIEND:
       g_value_set_boolean (value, priv->is_friend);
       break;
+    case PROP_SAFETY_LEVEL:
+      g_value_set_int (value, priv->safety_level);
+      break;
+    case PROP_CONTENT_TYPE:
+      g_value_set_int (value, priv->content_type);
+      break;
+    case PROP_SHOW_IN_SEARCH:
+      g_value_set_boolean (value, priv->show_in_search);
+      break;
     case PROP_PIXBUF:
       g_value_set_object (value, priv->pixbuf);
       break;
@@ -263,11 +289,18 @@ _frogr_picture_dispose (GObject* object)
       priv->pixbuf = NULL;
     }
 
-  if (priv->albums)
+  if (priv->sets)
     {
-      g_slist_foreach (priv->albums, (GFunc) g_object_unref, NULL);
-      g_slist_free (priv->albums);
-      priv->albums = NULL;
+      g_slist_foreach (priv->sets, (GFunc) g_object_unref, NULL);
+      g_slist_free (priv->sets);
+      priv->sets = NULL;
+    }
+
+  if (priv->groups)
+    {
+      g_slist_foreach (priv->groups, (GFunc) g_object_unref, NULL);
+      g_slist_free (priv->groups);
+      priv->groups = NULL;
     }
 
   /* call super class */
@@ -370,6 +403,35 @@ frogr_picture_class_init(FrogrPictureClass *klass)
                                                          "friends or not",
                                                          FALSE,
                                                          G_PARAM_READWRITE));
+  g_object_class_install_property (obj_class,
+                                   PROP_SAFETY_LEVEL,
+                                   g_param_spec_int ("safety-level",
+                                                     "safety-level",
+                                                     "Safety level for this picture "
+                                                     "(safe/moderate/restricted)",
+                                                     FSP_SAFETY_LEVEL_NONE,
+                                                     FSP_SAFETY_LEVEL_RESTRICTED,
+                                                     FSP_SAFETY_LEVEL_SAFE,
+                                                     G_PARAM_READWRITE));
+  g_object_class_install_property (obj_class,
+                                   PROP_CONTENT_TYPE,
+                                   g_param_spec_int ("content-type",
+                                                     "content-type",
+                                                     "Content type for this picture "
+                                                     "(photo/screenshot/other)",
+                                                     FSP_CONTENT_TYPE_NONE,
+                                                     FSP_CONTENT_TYPE_OTHER,
+                                                     FSP_CONTENT_TYPE_PHOTO,
+                                                     G_PARAM_READWRITE));
+  g_object_class_install_property (obj_class,
+                                   PROP_SHOW_IN_SEARCH,
+                                   g_param_spec_boolean ("show-in-search",
+                                                         "show-in-search",
+                                                         "Whether the show the "
+                                                         "picture in global "
+                                                         "search results",
+                                                         FALSE,
+                                                         G_PARAM_READWRITE));
   g_object_class_install_property (obj_class,
                                    PROP_PIXBUF,
                                    g_param_spec_object ("pixbuf",
@@ -395,12 +457,17 @@ frogr_picture_init (FrogrPicture *self)
   priv->tags_string = NULL;
 
   priv->tags_list = NULL;
-  priv->albums = NULL;
+  priv->sets = NULL;
+  priv->groups = NULL;
 
   priv->is_public = FALSE;
   priv->is_friend = FALSE;
   priv->is_family = FALSE;
 
+  priv->safety_level = FSP_SAFETY_LEVEL_SAFE;
+  priv->content_type = FSP_CONTENT_TYPE_PHOTO;
+  priv->show_in_search = TRUE;
+
   priv->pixbuf = NULL;
 }
 
@@ -410,7 +477,9 @@ frogr_picture_init (FrogrPicture *self)
 FrogrPicture *
 frogr_picture_new (const gchar *filepath,
                    const gchar *title,
-                   gboolean public)
+                   gboolean public,
+                   gboolean family,
+                   gboolean friend)
 {
   g_return_val_if_fail (filepath, NULL);
   g_return_val_if_fail (title, NULL);
@@ -419,6 +488,11 @@ frogr_picture_new (const gchar *filepath,
                               "filepath", filepath,
                               "title", title,
                               "is-public", public,
+                              "is-family", family,
+                              "is-friend", friend,
+                              "safety-level", FSP_SAFETY_LEVEL_SAFE,
+                              "content-type", FSP_CONTENT_TYPE_PHOTO,
+                              "show_in_search", TRUE,
                               NULL);
   return FROGR_PICTURE (new);
 }
@@ -571,6 +645,14 @@ frogr_picture_add_tags (FrogrPicture *self, const gchar *tags_string)
   _add_tags_to_tags_list (self, tags_string);
 }
 
+void
+frogr_picture_remove_tags (FrogrPicture *self)
+{
+  g_return_if_fail(FROGR_IS_PICTURE(self));
+
+  frogr_picture_set_tags (self, NULL);
+}
+
 gboolean
 frogr_picture_is_public (FrogrPicture *self)
 {
@@ -640,6 +722,75 @@ frogr_picture_set_family (FrogrPicture *self,
   priv->is_family = family;
 }
 
+FspSafetyLevel
+frogr_picture_get_safety_level (FrogrPicture *self)
+{
+  g_return_val_if_fail(FROGR_IS_PICTURE(self), FALSE);
+
+  FrogrPicturePrivate *priv =
+    FROGR_PICTURE_GET_PRIVATE (self);
+
+  return priv->safety_level;
+}
+
+void
+frogr_picture_set_safety_level (FrogrPicture *self,
+                                FspSafetyLevel safety_level)
+{
+  g_return_if_fail(FROGR_IS_PICTURE(self));
+
+  FrogrPicturePrivate *priv =
+    FROGR_PICTURE_GET_PRIVATE (self);
+
+  priv->safety_level = safety_level;
+}
+
+FspContentType
+frogr_picture_get_content_type (FrogrPicture *self)
+{
+  g_return_val_if_fail(FROGR_IS_PICTURE(self), FALSE);
+
+  FrogrPicturePrivate *priv =
+    FROGR_PICTURE_GET_PRIVATE (self);
+
+  return priv->content_type;
+}
+
+void
+frogr_picture_set_content_type (FrogrPicture *self,
+                                FspContentType content_type)
+{
+  g_return_if_fail(FROGR_IS_PICTURE(self));
+
+  FrogrPicturePrivate *priv =
+    FROGR_PICTURE_GET_PRIVATE (self);
+
+  priv->content_type = content_type;
+}
+
+gboolean
+frogr_picture_show_in_search (FrogrPicture *self)
+{
+  g_return_val_if_fail(FROGR_IS_PICTURE(self), FALSE);
+
+  FrogrPicturePrivate *priv =
+    FROGR_PICTURE_GET_PRIVATE (self);
+
+  return priv->show_in_search;
+}
+
+void
+frogr_picture_set_show_in_search (FrogrPicture *self,
+                                  gboolean show_in_search)
+{
+  g_return_if_fail(FROGR_IS_PICTURE(self));
+
+  FrogrPicturePrivate *priv =
+    FROGR_PICTURE_GET_PRIVATE (self);
+
+  priv->show_in_search = show_in_search;
+}
+
 GdkPixbuf *
 frogr_picture_get_pixbuf (FrogrPicture *self)
 {
@@ -660,67 +811,141 @@ frogr_picture_set_pixbuf (FrogrPicture *self,
   FrogrPicturePrivate *priv =
     FROGR_PICTURE_GET_PRIVATE (self);
 
-  /* Unref previous pixbuf, if present */
   if (priv->pixbuf)
-    {
-      g_object_unref (priv->pixbuf);
-      priv->pixbuf = NULL;
-    }
+    g_object_unref (priv->pixbuf);
 
-  /* Add new pixbuf, if not NULL */
-  if (pixbuf)
-    {
-      priv->pixbuf = pixbuf;
-      g_object_ref (priv->pixbuf);
-    }
+  priv->pixbuf = GDK_IS_PIXBUF (pixbuf) ? g_object_ref (pixbuf) : NULL;
 }
 
 GSList *
-frogr_picture_get_albums (FrogrPicture *self)
+frogr_picture_get_sets (FrogrPicture *self)
 {
   g_return_val_if_fail(FROGR_IS_PICTURE(self), NULL);
 
   FrogrPicturePrivate *priv = NULL;
 
   priv = FROGR_PICTURE_GET_PRIVATE (self);
-  return priv->albums;
+  return priv->sets;
 }
 
 void
-frogr_picture_set_albums (FrogrPicture *self, GSList *albums)
+frogr_picture_set_sets (FrogrPicture *self, GSList *sets)
 {
   g_return_if_fail(FROGR_IS_PICTURE(self));
 
   GSList *new_list = NULL;
   GSList *item = NULL;
-  FrogrAlbum *album = NULL;
+  FrogrPhotoSet *set = NULL;
   FrogrPicturePrivate *priv = NULL;
 
   priv = FROGR_PICTURE_GET_PRIVATE (self);
 
-  /* First remove all the previous albums list */
-  g_slist_foreach (priv->albums, (GFunc) g_object_unref, NULL);
-  g_slist_free (priv->albums);
-  priv->albums = NULL;
+  /* First remove all the previous sets list */
+  g_slist_foreach (priv->sets, (GFunc) g_object_unref, NULL);
+  g_slist_free (priv->sets);
+  priv->sets = NULL;
 
-  for (item = albums; item; item = g_slist_next (item))
+  for (item = sets; item; item = g_slist_next (item))
     {
-      album = FROGR_ALBUM (item->data);
-      new_list = g_slist_append (new_list, g_object_ref (album));
+      set = FROGR_PHOTOSET (item->data);
+      new_list = g_slist_append (new_list, g_object_ref (set));
     }
 
-  priv->albums = new_list;
+  priv->sets = new_list;
+}
+
+void
+frogr_picture_add_set (FrogrPicture *self, FrogrPhotoSet *set)
+{
+  g_return_if_fail(FROGR_IS_PICTURE(self));
+  g_return_if_fail(FROGR_IS_SET(set));
+
+  FrogrPicturePrivate *priv = NULL;
+
+  /* Do not add the same set twice */
+  if (frogr_picture_in_set (self, set))
+    return;
+
+  priv = FROGR_PICTURE_GET_PRIVATE (self);
+  priv->sets = g_slist_append (priv->sets, g_object_ref (set));
+}
+
+void
+frogr_picture_remove_sets (FrogrPicture *self)
+{
+  g_return_if_fail(FROGR_IS_PICTURE(self));
+
+  frogr_picture_set_sets (self, NULL);
 }
 
 gboolean
-frogr_picture_in_album (FrogrPicture *self, FrogrAlbum *album)
+frogr_picture_in_set (FrogrPicture *self, FrogrPhotoSet *set)
 {
   g_return_val_if_fail(FROGR_IS_PICTURE(self), FALSE);
 
   FrogrPicturePrivate *priv = NULL;
 
   priv = FROGR_PICTURE_GET_PRIVATE (self);
-  if (g_slist_index (priv->albums, album) != -1)
+  if (g_slist_index (priv->sets, set) != -1)
+    return TRUE;
+
+  return FALSE;
+}
+
+GSList *
+frogr_picture_get_groups (FrogrPicture *self)
+{
+  g_return_val_if_fail(FROGR_IS_PICTURE(self), NULL);
+
+  FrogrPicturePrivate *priv = NULL;
+
+  priv = FROGR_PICTURE_GET_PRIVATE (self);
+  return priv->groups;
+}
+
+void
+frogr_picture_set_groups (FrogrPicture *self, GSList *groups)
+{
+  g_return_if_fail(FROGR_IS_PICTURE(self));
+
+  GSList *new_list = NULL;
+  GSList *item = NULL;
+  FrogrGroup *group = NULL;
+  FrogrPicturePrivate *priv = NULL;
+
+  priv = FROGR_PICTURE_GET_PRIVATE (self);
+
+  /* First remove all the previous groups list */
+  g_slist_foreach (priv->groups, (GFunc) g_object_unref, NULL);
+  g_slist_free (priv->groups);
+  priv->groups = NULL;
+
+  for (item = groups; item; item = g_slist_next (item))
+    {
+      group = FROGR_GROUP (item->data);
+      new_list = g_slist_append (new_list, g_object_ref (group));
+    }
+
+  priv->groups = new_list;
+}
+
+void
+frogr_picture_remove_groups (FrogrPicture *self)
+{
+  g_return_if_fail(FROGR_IS_PICTURE(self));
+
+  frogr_picture_set_groups (self, NULL);
+}
+
+gboolean
+frogr_picture_in_group (FrogrPicture *self, FrogrGroup *group)
+{
+  g_return_val_if_fail(FROGR_IS_PICTURE(self), FALSE);
+
+  FrogrPicturePrivate *priv = NULL;
+
+  priv = FROGR_PICTURE_GET_PRIVATE (self);
+  if (g_slist_index (priv->groups, group) != -1)
     return TRUE;
 
   return FALSE;
